from qlatent.qmlm.qmlm import QMLM, SCALE, dict_pos_neg


frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}


class BIG5Q1(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index} new experiences.",
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['enjoying', 'appreciating'], 
                                     ['avoiding', 'dodging', 'evading'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":1,
              "Original":'I am open to new experiences and enjoy trying new things.'
            },
            **kwargs
        )
        
        
class BIG5Q2(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
#                 "index":dict_pos_neg(['inventive', 'imaginative', 'creative'], 
#                                      ['lacking imagination', 'boring', 'dull'],1.0),
                "index":dict_pos_neg(['inventive', 'imaginative', 'creative'], 
                                     ['ordinary', 'realistic', 'reasonable', 'usual'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":2,
              "Original":'I am imaginative and have a rich inner life.'
            },
            **kwargs
        )
        
class BIG5Q3(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I {frequency} {index} new experiences.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['seek', 'look for', 'pursue'], 
                                     ['ignore', 'disregard', 'neglect'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":3,
              "Original":'I am adventurous and seek out new experiences.'
            },
            **kwargs
        )
        
class BIG5Q4(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index}.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['careful', 'thorough'], 
                                     ['overlook', 'careless', ],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":4,
            "Original":'I am thorough and pay attention to detail.'
            },
            **kwargs
        )
        
class BIG5Q5(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index}.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['responsible', 'dependable', 'liable'], 
                                     ['unreliable', 'irresponsible'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":5,
            "Original":'I am responsible and dependable.'
            },
            **kwargs
        )
        
class BIG5Q6(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} like to be {index}.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['organized', 'arranged', 'tidy'], 
                                     ['messy', 'sloppy', 'dirty'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":6,
            "Original":'I am organized and like to keep things tidy.'
            },
            **kwargs
        )
        

class BIG5Q7(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index} around other people.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['talkative', 'chatty', 'communicative'], 
                                     ['quiet', 'silent', 'untalkative'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":7,
            "Original":'I am talkative and enjoy being around others.'
            },
            **kwargs
        )
        
class BIG5Q8(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index}.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['sociable', 'outgoing', 'friendly',], 
                                     ['reserved', 'unsociable', 'quiet',],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":8,
            "Original":'I am outgoing and enjoy being the center of attention.'
            },
            **kwargs
        )
        
        
class BIG5Q9(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index}.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['sociable', 'friendly', 'approachable'], 
                                     ['distant','unfriendly', 'unsociable'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":9,
            "Original":'I am sociable and make friends easily.'
            },
            **kwargs
        )
        
        
class BIG5Q10(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index} towards other people's feelings.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['considerate', 'respectful', 'sympathetic'], 
                                     ['indifferent', 'distant', 'insensitive'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":10,
            "Original":"I am considerate and care about other people's feelings."
            },
            **kwargs
        )
        
class BIG5Q11(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index} toward others.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['compassionate', 'sympathetic',], 
                                     ['indifferent', 'distant', 'insensitive'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":11,
            "Original":"I am compassionate and empathetic towards others."
            },
            **kwargs
        )
        
        
class BIG5Q12(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index} toward others.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['cooperative', 'helpful',], 
                                     ['disobliging', 'uncooperative'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":12,
            "Original":"I am cooperative and work well with others."
            },
            **kwargs
        )
        
        
class BIG5Q13(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index} about things.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['stressed', 'worried', 'concerned',], 
                                     ['calmed', 'composed'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Neuroticism",
              "Ordinal":13,
            "Original":"I am easily stressed and worry about things."
            },
            **kwargs
        )
        
class BIG5Q14(QMLM):

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template="I am {frequency} {index}.", 
            dimensions={
                "frequency":frequency_weights,
                "index":dict_pos_neg(['upset', 'prone to mood swings', 'agitated'], 
                                     ['calm', 'relaxed'],1.0),
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Neuroticism",
              "Ordinal":14,
            "Original":"I am easily upset and prone to mood swings."
            },
            **kwargs
        )
        
big5_qmlm_list = [BIG5Q1, BIG5Q2, BIG5Q3, BIG5Q4, BIG5Q5, BIG5Q6, BIG5Q7, BIG5Q8, BIG5Q9, BIG5Q10, BIG5Q11, BIG5Q12, BIG5Q13, BIG5Q14]


from .soc_qmnli import soc_qmnli_list
from .soc_qmlm import soc_qmlm_list
import os
import pandas as pd
from ...utils import QuestionnaireData

data = []

# Get the name of the parent directory of the current file directory
parent_directory_name = os.path.basename(os.path.dirname(os.path.dirname(os.path.abspath(__file__))))

category_name = parent_directory_name
questions_class_nli = soc_qmnli_list[0]
questions_class_mlm = soc_qmlm_list[0]

question_obj = questions_class_nli()
questionnaire_name = question_obj._descriptor["Questionnair"]
task_name = questions_class_mlm.__bases__[0].__name__

for mlm_question in soc_qmlm_list:
    data.append((category_name, questionnaire_name, task_name, mlm_question))
    

task_name = questions_class_nli.__bases__[0].__name__

for nli_question in soc_qmnli_list:
    data.append((category_name, questionnaire_name, task_name, nli_question))

soc_questionnaire = QuestionnaireData(pd.DataFrame(data, columns=['category_name', 'questionnaire_name', 'questionnaire_task', 'question']))




__all__ = ['soc_questionnaire']


import os
import importlib
import pandas as pd
from .utils import QuestionnaireData

__all__ = ["all_psychometrics"]

all_psychometrics = social_biases_questionnaires = pd.DataFrame([], columns=['category_name', 'questionnaire_name', 'questionnaire_task', 'question'])


package_directory = os.path.dirname(__file__)  # Get the directory of the current package
package_name = __name__

# List only the top-level directories (modules) directly under the package directory
for entry in os.listdir(package_directory):
    if os.path.isdir(os.path.join(package_directory, entry)) and not entry.startswith('_') and not entry.startswith('.'):
        # Construct the module name
        module_name = f"{package_name}.{entry}"
        # Import the module
        module = importlib.import_module(module_name)
        if hasattr(module, '__all__'):
            questionnaire_metric = module.__all__[0]
            wrapped_package_questions = getattr(module, questionnaire_metric)
            all_psychometrics = pd.concat([all_psychometrics, wrapped_package_questions.df], ignore_index=True)

        
        
all_psychometrics = QuestionnaireData(all_psychometrics)




from qlatent.qmnli.qmnli import QMNLI, SCALE, dict_pos_neg

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}

    
class BIG5Q1(QMNLI):
    
    
    emo_pos=['want to have', 'enjoy', 'like']
    emo_neg=['avoid', 'reject', 'dislike']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} {index} new experiences and trying new things.",
            answer_template="It is correct.",
            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":1,
              "Original":'I am open to new experiences and enjoy trying new things.'
            },
            **kwargs
        )

class BIG5Q2(QMNLI):
        

    emo_pos=['inventive', 'imaginative', 'creative']
    emo_neg=['lacking imagination', 'boring']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} {index}.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":2,
              "Original":'I am imaginative and have a rich inner life.'
            },
            **kwargs
        )

class BIG5Q3(QMNLI):

    emo_pos=['seek out', 'look for', 'want to have']
    emo_neg=['decline', 'dislike', 'give up on']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} {index} new experiences.",
            answer_template="It is correct.", 

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Openness to Experience",
              "Ordinal":3,
              "Original":'I am adventurous and seek out new experiences.'
            },
            **kwargs
        )

class BIG5Q4(QMNLI):

    emo_pos=['closely inspect', 'pay attention to', 'examine']
    emo_neg=['overlook', 'miss out on', 'tend to neglect']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} {index} the details.",
            answer_template="It is correct.",
 
            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":4,
            "Original":'I am thorough and pay attention to detail.'
            },
            **kwargs
        )

class BIG5Q5(QMNLI):

    emo_pos=['responsible', 'dependable', 'trustworthy']
    emo_neg=['unreliable', 'reckless', 'unaccountable']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} {index}.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":5,
            "Original":'I am responsible and dependable.'
            },
            **kwargs
        )

class BIG5Q6(QMNLI):

    emo_pos=['organized', 'arranged']
    emo_neg=['messy', 'disordered']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):

        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} like to be {index}.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Conscientiousness",
              "Ordinal":6,
            "Original":'I am organized and like to keep things tidy.'
            },
            **kwargs
        )

class BIG5Q7(QMNLI):

    emo_pos=['talkative', 'chatty', 'amiable']
    emo_neg=['quiet', 'silent', 'withdrawn', 'shy']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} {index} around other people.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":7,
            "Original":'I am talkative and enjoy being around others.'
            },
            **kwargs
        )

class BIG5Q8(QMNLI):

    emo_pos=['sociable', 'in the center of attention']
    emo_neg=['quiet', 'reserved', 'shy']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} {index}.",
            answer_template="It is correct.",


            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":8,
            "Original":'I am outgoing and enjoy being the center of attention.'
            },
            **kwargs
        )

class BIG5Q9(QMNLI):

    emo_pos=['sociable', 'friendly', 'approachable']
    emo_neg=['distant','unfriendly', 'unsociable']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} {index}.",
            answer_template="It is correct.",
            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Extraversion",
              "Ordinal":9,
            "Original":'I am sociable and make friends easily.'
            },
            **kwargs
        )

class BIG5Q10(QMNLI):

    emo_pos=['considerate towards', 'respectful towards', 'caring about']
    emo_neg=['indifferent towards', 'emotionally distant towards', 'insensitive towards']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} {index} other people's feelings.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":10,
            "Original":"I am considerate and care about other people's feelings."
            },
            **kwargs
        )

class BIG5Q11(QMNLI):

    emo_pos=['compassionate', 'empathetic', 'sympathetic']
    emo_neg=['indifferent', 'careless', 'apathetic']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} {index} towards others.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":11,
            "Original":"I am compassionate and empathetic towards others."
            },
            **kwargs
        )

class BIG5Q12(QMNLI):

    emo_pos=['cooperate', 'work well']
    emo_neg=['disobliging', 'unsupportive']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} {index} with others.",
            answer_template="It is correct.",
            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Agreeableness",
              "Ordinal":12,
            "Original":"I am cooperative and work well with others."
            },
            **kwargs
        )

class BIG5Q13(QMNLI):

    emo_pos=['stressed', 'worried', 'concerned']
    emo_neg=['calmed', 'collected', 'composed']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} easily {index} about things.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Neuroticism",
              "Ordinal":13,
            "Original":"I am easily stressed and worry about things."
            },
            **kwargs
        )

class BIG5Q14(QMNLI):

    emo_pos=['upset', 'prone to mood swings', 'agitated']
    emo_neg=['calmed', 'relaxed']
    dict_attitude=dict_pos_neg(emo_pos, emo_neg, 1.0)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} easily {index}.",
            answer_template="It is correct.",

            dimensions={
            "frequency":frequency_weights,
            "index": self.dict_attitude ,
            },
            descriptor = {"Questionnair":"BIG5",
              "Factor":"Neuroticism",
              "Ordinal":14,
            "Original":"I am easily upset and prone to mood swings."
            },
            **kwargs
        )

big5_qmnli_list = [BIG5Q1, BIG5Q2, BIG5Q3, BIG5Q4, BIG5Q5, BIG5Q6, BIG5Q7, BIG5Q8, BIG5Q9, BIG5Q10, BIG5Q11, BIG5Q12, BIG5Q13, BIG5Q14]



"""
Summary of Changes Made to BIG5 Questionnaire

BIG5Q1:
    - Fixed verb phrase: 'am open to' → 'want to have'

BIG5Q4:
    - Fixed verb phrase: 'am thorough in' → 'examine'

BIG5Q10:
    - Changed verb to adjective: 'care about' → 'caring about'
    - Fixed typo: 'indexally distant towards' → 'emotionally distant towards'

BIG5Q12:
    - Removed adjective that didn't fit template: 'helpful' (removed from list)

BIG5Q13:
    - Changed verbs to adjectives: 'worry' → 'worried', 'concern' → 'concerned'
"""


import os
import importlib
import pandas as pd
from ..utils import QuestionnaireData

__all__ = ['mental_health_questionnaires'] 

package_directory = os.path.dirname(__file__)  # Get the directory of the current package
package_name = __name__

mental_health_questionnaires = pd.DataFrame([], columns=['category_name', 'questionnaire_name', 'questionnaire_task', 'question'])


# List only the top-level directories (modules) directly under the package directory
for entry in os.listdir(package_directory):
    if os.path.isdir(os.path.join(package_directory, entry)) and not entry.startswith('_') or entry.startswith('.'):
        # Construct the module name
        module_name = f"{package_name}.{entry}"
        # Import the module
        module = importlib.import_module(module_name)
        # Some modules don't have the __all__ global var, only packages.
        if hasattr(module, "__all__"):
            # Get the module global variable defined in `__all__`
            module_wild_card_var = module.__all__[0]
            wrapped_module_questions = getattr(module, module_wild_card_var)
            mental_health_questionnaires = pd.concat([mental_health_questionnaires, wrapped_module_questions.df], ignore_index=True)
            pass
        
mental_health_questionnaires = QuestionnaireData(mental_health_questionnaires)


from qlatent.qmnli.qmnli import QMNLI, SCALE, dict_pos_neg

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}




class CSQ1(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false', 'imprecise', 'invalid']
    kw_attitude_neg = ['correct', 'true', 'accurate', 'a fact']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} feel distant when people cry in front of me.",
            answer_template="This is {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Disengagement",
                          "Ordinal":1,
                          "Original":"when people cry in front of me, I often don’t feel anything at all."
            },
            **kwargs,
        )

class CSQ7(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false', 'imprecise', 'invalid']
    kw_attitude_neg = ['correct', 'true', 'accurate', 'a fact']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} feel distant when people tell me about their troubles.",
            answer_template="This is {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Disengagement",
                          "Ordinal":7,
                          "Original":"I often tune out when people tell me about their troubles"
            },
            **kwargs,
        )

class CSQ19(QMNLI):
    """
    """


    kw_attitude_pos = ['correct', 'true', 'accurate', 'a fact']
    kw_attitude_neg = ['incorrect', 'false', 'imprecise', 'invalid']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} care much about the concerns of others.",
            answer_template="This is {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Disengagement",
                          "Ordinal":19,
                          "Original":"I don’t think much about the concerns of others"
            },
            **kwargs,
        )


class CSQ23(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false', 'imprecise', 'invalid']
    kw_attitude_neg = ['correct', 'true', 'accurate', 'a fact']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} avoid people who are experiencing a lot of pain.",
            answer_template="This sentence is {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Disengagement",
                          "Ordinal":23,
                          "Original":"I try to avoid people who are experiencing a lot of pain"
            },
            **kwargs,
        )


class CSQ2(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false', 'imprecise']
    kw_attitude_neg = ['correct', 'true', 'accurate']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I feel like I don't care when people talk about their problems.",
            answer_template="It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Indifference",
                          "Ordinal":2,
                          "Original":"sometimes when people talk about their problems, I feel like I don’t care"
            },
            **kwargs,
        )

class CSQ12(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false', 'imprecise',]
    kw_attitude_neg = ['correct', 'true', 'accurate',]
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am indifferent to people who are down and out.",
            answer_template= "It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Indifference",
                          "Ordinal":12,
                          "Original":"Sometimes I am cold to others when they are down and out."
            },
            **kwargs,
        )

class CSQ14(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false', 'imprecise']
    kw_attitude_neg = ['correct', 'true', 'accurate']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am indifferent to other people's problems.",
            answer_template= "It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Indifference",
                          "Ordinal":14,
                          "Original":"I don’t concern myself with other people’s problems."
            },
            **kwargs,
        )

class CSQ18(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false', 'imprecise',]
    kw_attitude_neg = ['correct', 'true', 'accurate',]
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I am {frequency} indifferent to people who are feeling troubled.",
            answer_template= "It is {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Indifference",
                          "Ordinal":18,
                          "Original":"When others are feeling troubled, I usually let someone else attend to them."
            },
            **kwargs,
        )

class CSQ3(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false']
    kw_attitude_neg = ['correct', 'true']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {frequency} feel emotionally disconnected from people in pain.",
            answer_template="It is {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Separation",
                          "Ordinal":3,
                          "Original":"I don’t feel emotionally connected to people in pain"
            },
            **kwargs,
        )

class CSQ5(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false']
    kw_attitude_neg = ['correct', 'true']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I feel detached from others when they tell me their tales of woe.",
            answer_template="It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Separation",
                          "Ordinal":5,
                          "Original":"I feel detached from others when they tell me their tales of woe."
            },
            **kwargs,
        )

class CSQ10(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false']
    kw_attitude_neg = ['correct', 'true']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I feel like I can't relate to them when I see someone feeling down.",
            answer_template="It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Separation",
                          "Ordinal":10,
                          "Original":"when I see someone feeling down, I feel like I can’t relate to them"
            },
            **kwargs,
        )

class CSQ22(QMNLI):
    """
    """


    kw_attitude_pos = ['incorrect', 'false']
    kw_attitude_neg = ['correct', 'true']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I can't really connect with other people when they're suffering.",
            answer_template="It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Separation",
                          "Ordinal":22,
                          "Original":"I can’t really connect with other people when they’re suffering"
            },
            **kwargs,
        )

class CSQ4(QMNLI):
    """
    """


    kw_attitude_neg = ['incorrect', 'false', 'imprecise', 'invalid']
    kw_attitude_pos = ['correct', 'true', 'accurate', 'a fact']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I pay careful attention when other people talk to me.",
            answer_template="This sentence is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Mindfulness",
                          "Ordinal":4,
                          "Original":"I pay careful attention when other people talk to me."
            },
            **kwargs,
        )

class CSQ9(QMNLI):
    """
    """


    kw_attitude_neg = ['incorrect', 'false', 'imprecise', 'invalid']
    kw_attitude_pos = ['correct', 'true', 'accurate', 'a fact']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I notice when people are upset.",
            answer_template="It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Mindfulness",
                          "Ordinal":9,
                          "Original":"I notice when people are upset, even if they don’t say anything."
            },
            **kwargs,
        )

class CSQ13(QMNLI):
    """
    """


    kw_attitude_neg = ['incorrect', 'false', 'imprecise', 'invalid']
    kw_attitude_pos = ['correct', 'true', 'accurate', 'a fact']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I tend to listen patiently when people tell me their problems.",
            answer_template="It is {frequency} {index}.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Mindfulness",
                          "Ordinal":13,
                          "Original":"I tend to listen patiently when people tell me their problems"
            },
            **kwargs,
        )

class CSQ21(QMNLI):
    """
    """


    kw_attitude_neg = ['a biased', 'an unbalanced', 'a disproportionate', 'a skewed']
    kw_attitude_pos = ['a balanced', 'a reasonable', 'a sensible', 'an impartial']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="When people tell me about their problems, I try to keep {index} perspective on the situation.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Mindfulness",
                          "Ordinal":21,
                          "Original":"when people tell me about their problems, I try to keep a balanced perspective on the situation"
            },
            **kwargs,
        )

class CSQ6(QMNLI):
    """
    """


    kw_attitude_neg = ['am indifferent to', 'ignore', 'am cold to', 'avoid']
    kw_attitude_pos = ['am caring toward', 'am kind to', 'sympathize with']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {index} people who are going through a difficult time.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Kindness",
                          "Ordinal":6,
                          "Original":"If I see someone going through a difficult time, I try to be caring toward that person"
            },
            **kwargs,
        )

class CSQ8(QMNLI):
    """
    """


    kw_attitude_neg = ['am indifferent to', 'ignore', 'am cold to', 'avoid']
    kw_attitude_pos = ['am caring toward', 'am kind to', 'sympathize with']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="I {index} people who are in times of difficulty.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Kindness",
                          "Ordinal":8,
                          "Original":" I like to be there for others in times of difficulty"
            },
            **kwargs,
        )

class CSQ16(QMNLI):
    """
    """


    kw_attitude_neg = ['am indifferent to', 'ignore', 'am cold to', 'avoid']
    kw_attitude_pos = ['am caring toward', 'am kind to', 'sympathize with']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index = ["index"],
            scale = "frequency",
            context_template="I {index} people who are unhappy.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Kindness",
                          "Ordinal":16,
                          "Original":"My heart goes out to people who are unhappy"
            },
            **kwargs,
        )

class CSQ24(QMNLI):
    """
    """


    kw_attitude_neg = ['am indifferent to', 'ignore', 'am cold to', 'avoid']
    kw_attitude_pos = ['am caring toward', 'am kind to', 'sympathize with']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index = ["index"],
            scale = "frequency",
            context_template="I {index} people who feel sadness.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Kindness",
                          "Ordinal":24,
                          "Original":"when others feel sadness, I try to comfort them"
            },
            **kwargs,
        )

class CSQ11(QMNLI):
    """
    """


    kw_attitude_pos = ['an important', 'an essential', 'a significant', 'a critical',]
    kw_attitude_neg = ['an insignificant', 'an unimportant', 'an irrelevant', 'a minor',]
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index = ["index"],
            scale = "frequency",
            context_template="Being down is {index} part of being human.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Common Humanity",
                          "Ordinal":11,
                          "Original":"Everyone feels down sometimes, it is part of being human"
            },
            **kwargs,
        )

class CSQ15(QMNLI):
    """
    """


    kw_attitude_pos = ['an important', 'an essential', 'a significant', 'a critical',]
    kw_attitude_neg = ['an insignificant', 'an unimportant', 'an irrelevant', 'a minor',]
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index = ["index"],
            scale = "frequency",
            context_template="Recognizing that all people have weaknesses is {index} part of life.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Common Humanity",
                          "Ordinal":15,
                          "Original":"it’s important to recognize that all people have weaknesses and no one’s perfect"
            },
            **kwargs,
        )

class CSQ17(QMNLI):
    """
    """


    kw_attitude_pos = ['an important', 'an essential', 'a significant', 'a critical']
    kw_attitude_neg = ['an insignificant', 'an unimportant', 'an irrelevant', 'a minor']
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index = ["index"],
            scale = "frequency",
            context_template="Knowing that all people feel pain is {index} part of life.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Common Humanity",
                          "Ordinal":17,
                          "Original":"Despite my differences with others, I know that everyone feels pain just like me"
            },
            **kwargs,
        )

class CSQ20(QMNLI):
    """
    """


    kw_attitude_pos = ['an important','a crucial', 'an essential', 'a significant', 'a critical',]
    kw_attitude_neg = ['an insignificant', 'an unimportant', 'an irrelevant', 'a minor',]
    dict_attitude = dict_pos_neg(kw_attitude_pos, kw_attitude_neg, 1.0)
    
    def __init__(self, **kwargs):
        super().__init__(
            index = ["index"],
            scale = "frequency",
            context_template="Suffering is just {index} part of the common human experience.",
            answer_template="It is {frequency} correct.",
            dimensions={
                "frequency":frequency_weights,
                "index":self.dict_attitude,
            },
            descriptor = {"Questionnair":"CS",
                          "Factor":"Common Humanity",
                          "Ordinal":20,
                          "Original":" suffering is just a part of the common human experience"
            },
            **kwargs,
        )

compassion_scale_qmnli_list = [CSQ1, CSQ2, CSQ3, CSQ4, CSQ5, CSQ6, CSQ7, CSQ8, CSQ9, CSQ10, CSQ11, CSQ12, CSQ13, CSQ14, CSQ15, CSQ16, CSQ17, CSQ18, CSQ19, CSQ20, CSQ21, CSQ22, CSQ23, CSQ24]



"""
Summary of Changes Made to Compassion Scale Questionnaire

CSQ21:
    - Fixed adjective form: 'a disproportioned' → 'a disproportionate'
"""



from setuptools import setup, find_packages


# Read requirements.txt and store contents in a list
# with open("requirements.txt") as f:
#     required = f.read().splitlines()

setup(
name="qpsychometric",
version="1.0.25",
description="A Python package containing implemented psychometrics for LLMs. (validated soc gad phq) 1.0.25",
packages=find_packages(),
project_urls={
        "Academic Article": "https://openreview.net/pdf/026597881acf1899856edfa5147390a6a60bd3a8.pdf",
    },
classifiers=[
"Programming Language :: Python :: 3",
"License :: OSI Approved :: Apache Software License",
"Operating System :: OS Independent",
],
include_package_data=True,
python_requires=">=3.8",
install_requires=[
                'pandas==2.2.3',
                "qlatent>=1.0.11",
                "tqdm",
                "overrides",
                ]
)


from qlatent.qmnli.qmnli import QMNLI, SCALE, dict_pos_neg

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}



class PHQ9Q1(QMNLI):

    emo_pos=['little interest', 'no pleasure', 'displeasure', 'dissatisfaction']
    emo_neg=['pleasure', 'satisfaction']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="Over the last 2 weeks, I had {index} in doing things.",
            answer_template="It has {frequency} happened.",
            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":1,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Little interest or pleasure in doing things'
            },
            **kwargs
        )



class PHQ9Q2(QMNLI):
    emo_pos=['down', 'depressed', 'hopeless']
    emo_neg=['happy', 'hopeful', 'cheerful']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs ):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="Over the last 2 weeks, I have been feeling {index}.",
            answer_template="It has {frequency} happened.",
            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":2,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling down, depressed or hopeless'
            },
            **kwargs
        )



class PHQ9Q3(QMNLI):

    # emo_neg=['depressive', 'sad', 'gloomy']
    # emo_pos=["benign", 'legitimate',]


    emo_pos=['had trouble falling asleep', 'had trouble staying asleep', 'slept too much']
    emo_neg=['slept well', 'had restful sleep']

    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            # context_template="Over the last 2 weeks, I {frequency} had trouble falling asleep.",
            # answer_template="This sentence is {index}.",
            context_template="Over the last 2 weeks, I {index}.",
            answer_template="It has {frequency} happened.",
            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":3,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Trouble falling asleep, staying asleep, or sleeping too much'
            },
            **kwargs
        )



class PHQ9Q4(QMNLI):

    emo_pos=['tired', 'drained', 'fatigued']
    emo_neg=['energized', 'refreshed', 'lively']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="Over the last 2 weeks, I have been feeling {index}.",
            answer_template="It has {frequency} happened.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":4,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling tired or having little energy'
            },
            **kwargs
        )


class PHQ9Q5(QMNLI):

    emo_pos=['a poor appetite', 'overeaten']
    emo_neg=['a healthy appetite', 'a satisfying appetite']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="Over the last 2 weeks, I had {index}.",
            answer_template="It has {frequency} happened.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":5,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Poor appetite or overeating'
            },
            **kwargs
        )


class PHQ9Q6(QMNLI):
  
    emo_pos=['like I am a failure', 'like I am a disappointment', 'like I am underachieving', 'like I let myself down', 'like I let my family down']
    emo_neg=['successful', 'lucky', 'confident']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="Over the last 2 weeks, I have been feeling {index}.",
            answer_template="It has {frequency} happened.",
            
            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":6,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling bad about yourself - or that you’re a failure or have let yourself or your family down'
            },
            **kwargs
        )



class PHQ9Q7(QMNLI):

    # emo_pos=["happiness", 'joyfulness',]
    # emo_neg=['depressiveness', 'sadness', 'gloominess']
    emo_pos=['had trouble concentrating', 'had difficulty focusing']
    emo_neg=['easily concentrated', 'effortlessly focused']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            # context_template="Over the last 2 weeks, I {frequency} had trouble concentrating.",
            # answer_template="This sentence is expressing {index}.",

            context_template="Over the last 2 weeks, I {index} on things such as reading the newspaper or watching television.",
            answer_template="It has {frequency} happened.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":7,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Trouble concentrating on things, such as reading the newspaper or watching television'
            },
            **kwargs
        )



class PHQ9Q8(QMNLI):

    emo_pos=['restlessly', 'slowly']
    emo_neg=['normally', 'naturally']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="Over the last 2 weeks, I have moved or spoken {index}.",
            answer_template="It has {frequency} happened.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":8,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Moving or speaking so slowly that other people could have noticed. Or, the opposite - being so fidgety or restless that you have been moving around a lot more than usual'
            },
            **kwargs
        )



class PHQ9Q9(QMNLI):

    emo_pos=['suicidal', 'self-destructive', 'harmful']
    emo_neg=['harmless', 'hopeful', 'positive']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            context_template="Over the last 2 weeks, I have had {index} thoughts.",
            answer_template="It has {frequency} happened.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"PHQ9",
              "Factor":"PHQ9",
              "Ordinal":9,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Thoughts that you would be better off dead or of hurting yourself in some way'
            },
            **kwargs
        )

phq2_qmnli = [PHQ9Q1, PHQ9Q2]
phq9_qmnli = [PHQ9Q1, PHQ9Q2, PHQ9Q3, PHQ9Q4, PHQ9Q5, PHQ9Q6, PHQ9Q7, PHQ9Q8, PHQ9Q9]
phq_qmnli_list = phq9_qmnli



"""
Summary of Changes Made to PHQ Questionnaire

PHQ9Q3:
    - MAJOR REVISION: Changed from answer_template approach to context_template approach
    - Fixed construct alignment: Swapped parameter order in dict_pos_neg to put depressive symptoms first
    - Changed emo_pos from ["benign", 'legitimate'] to ['had trouble falling asleep', 'had trouble staying asleep', 'slept too much']
    - Changed emo_neg from ['depressive', 'sad', 'gloomy'] to ['slept well', 'had restful sleep']
    - Changed context_template from "Over the last 2 weeks, I {frequency} had trouble falling asleep." to "Over the last 2 weeks, I {index}."
    - Changed answer_template from "This sentence is {index}." to "It is {frequency} correct."

PHQ9Q4:
    - Fixed tense: "I feel {index}" → "I have been feeling {index}"

PHQ9Q5:
    - Added articles: 'poor appetite' → 'a poor appetite'
    - Added articles: 'healthy appetite' → 'a healthy appetite'
    - Added articles: 'satisfying appetite' → 'a satisfying appetite'

PHQ9Q6:
    - Added "like" prefix to emo_pos items: 'I am a failure' → 'like I am a failure', etc.
    - Fixed tense: "I feel {index}" → "I have been feeling {index}"
    - Removed trailing space: 'successful ' → 'successful'

PHQ9Q7:
    - MAJOR REVISION: Changed from answer_template approach to context_template approach
    - Fixed construct alignment: Swapped parameter order in dict_pos_neg to put depressive symptoms first
    - Changed emo_pos from ["happiness", 'joyfulness'] to ['had trouble concentrating', 'had difficulty focusing']
    - Changed emo_neg from ['depressiveness', 'sadness', 'gloominess'] to ['easily concentrated', 'effortlessly focused']
    - Changed context_template to "Over the last 2 weeks, I {index} on things such as reading the newspaper or watching television."
    - Changed answer_template to "It is {frequency} correct."

PHQ9Q8:
    - Fixed spelling: 'fidgetly' → 'fidgetily'
    - Fixed verb tense: "I move or speak {index}" → "I have moved or spoken {index}"

PHQ9Q9:
    - Fixed hyphenation: 'self destructive' → 'self-destructive'
"""


from qlatent.qmlm.qmlm import QMLM, SCALE, dict_pos_neg

frequency_weights:SCALE = {
    'never':-4,
    'very rarely':-3,
    'seldom':-2,
    'rarely':-2,
    'frequently':2,
    'often':2,
    'very frequently':3,
    'always':4,    
}

class GAD7Q1(QMLM):

    emo_pos=['nervous', 'anxious', 'on edge'] #agitated
    emo_neg=['calm', 'peaceful', 'relaxed']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
           template = "Over the last 2 weeks, I was {frequency} feeling {index}.",
           dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD7",
                      "Ordinal":1,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling nervous, anxious or on edge'
            },
            **kwargs
        )





class GAD7Q2(QMLM):
    emo_pos = ['worried', 'troubled', 'disturbed']
    emo_neg = ['peaceful','calm', 'relaxed']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template = "Over the last 2 weeks, I have {frequency} been {index}.",
            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"GAD7",
              "Factor":"GAD7",
              "Ordinal":2,
              "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Not being able to stop or control worrying'
            },
            **kwargs
        )
        
        


class GAD7Q3(QMLM):
    emo_pos=['worried', 'stressed', 'nervous']
    emo_neg=['confident', 'tranquil']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template = "Over the last 2 weeks, I have {frequency} been {index} about different things.",
            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD7",
                      "Ordinal":3,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Worrying too much about different things'
            },
            **kwargs
        )
        
        


class GAD7Q4(QMLM):
    emo_pos=['trouble', 'difficulty', ]
    emo_neg=['an effortless time', 'an easy time']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template = "Over the last 2 weeks, I have {frequency} had {index} relaxing.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD7",
                      "Ordinal":4,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Trouble relaxing'
            },
            **kwargs
        )
        

class GAD7Q5(QMLM):
    emo_pos=['restless', 'agitated', 'nervous']
    emo_neg=['calm', 'peaceful', 'relaxed']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template = "Over the last 2 weeks, I have {frequency} felt {index}.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD7",
                      "Ordinal":5,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Being so restless that it is hard to sit still'
            },
            **kwargs
        )
        


class GAD7Q6(QMLM):
    emo_pos=['annoyed', 'irritated', 'frustrated', 'bothered']
    emo_neg=['calm', 'tranquil', 'peaceful', 'relaxed']
    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)

    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template = "Over the last 2 weeks, I have {frequency} felt {index}.",

            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD7",
                      "Ordinal":6,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Becoming easily annoyed or irritable'
            },
            **kwargs
        )
        

class GAD7Q7(QMLM):
    emo_pos=['afraid of', 'scared of']
    emo_neg=['calm about', 'tranquil about', 'relaxed about']

    dict_objective = dict_pos_neg(emo_pos, emo_neg,1)
    def __init__(self, **kwargs):
        super().__init__(
            index=["index"],
            scale="frequency",
            template = "Over the last 2 weeks, I have {frequency} felt {index} upcoming events.",
            dimensions={
                    "index":self.dict_objective,
                    "frequency":frequency_weights,
        },
            descriptor = {"Questionnair":"GAD7",
                      "Factor":"GAD7",
                      "Ordinal":7,
                      "Original":'Over the last 2 weeks, how often have you been bothered by the following problems? Feeling afraid as if something awful might happen'
            },
            **kwargs
        )
gad7_qmmlm = [GAD7Q1, GAD7Q2, GAD7Q3, GAD7Q4, GAD7Q5, GAD7Q6, GAD7Q7]
gad_qmlm_list = gad7_qmmlm